==> credentials-1.6-sources.jar: com/cloudbees/plugins/credentials/common/StandardCredentials.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2011-2012, CloudBees, Inc., Stephen Connolly.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.cloudbees.plugins.credentials.common;

import edu.umd.cs.findbugs.annotations.NonNull;

/**
 * Credentials that have a description to help the user differentiate the specific credential from a collection of
 * {@link com.cloudbees.plugins.credentials.Credentials} and an ID to help {@link jenkins.model.Jenkins} locate the
 * specific credential from a collection of {@link com.cloudbees.plugins.credentials.Credentials}. Most credentials
 * should aim to implement this interface.
 *
 * @since 1.6
 */
public interface StandardCredentials extends IdCredentials {
    /**
     * Returns the Description.
     *
     * @return the Description.
     */
    @NonNull
    String getDescription();
}

==> credentials-1.20-sources.jar: com/cloudbees/plugins/credentials/common/StandardCredentials.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2011-2012, CloudBees, Inc., Stephen Connolly.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.cloudbees.plugins.credentials.common;

import com.cloudbees.plugins.credentials.CredentialsNameProvider;
import com.cloudbees.plugins.credentials.NameWith;
import edu.umd.cs.findbugs.annotations.NonNull;
import hudson.Util;

/**
 * Credentials that have a description to help the user differentiate the specific credential from a collection of
 * {@link com.cloudbees.plugins.credentials.Credentials} and an ID to help {@link jenkins.model.Jenkins} locate the
 * specific credential from a collection of {@link com.cloudbees.plugins.credentials.Credentials}. Most credentials
 * should aim to implement this interface.
 *
 * @since 1.6
 */
@Recommended(since = "1.6")
@NameWith(value = StandardCredentials.NameProvider.class, priority = -16)
public interface StandardCredentials extends IdCredentials {
    /**
     * Returns the Description.
     *
     * @return the Description.
     */
    @NonNull
    String getDescription();

    /**
     * Our name provider.
     *
     * @since 1.7
     */
    public static class NameProvider extends CredentialsNameProvider<StandardCredentials> {

        /**
         * {@inheritDoc}
         */
        @NonNull
        @Override
        public String getName(@NonNull StandardCredentials c) {
            String description = Util.fixEmptyAndTrim(c.getDescription());
            return c.getId() + (description != null ? " (" + description + ")" : "");
        }
    }
}
